@@ -20,19 +20,21 @@
 #ifndef _CONSTANTS_H
 #define	_CONSTANTS_H
 
-#include <QDir>
 #include <QObject>
 #include <QString>
 
-#define ORG_NAME "net.launchpad.kdocker"
-#define DOM_NAME "launchpad.net/kdocker"
-#define APP_NAME "KDocker"
-#define APP_VERSION "4.2.2.1"
+class Constants : QObject {
+    Q_OBJECT
 
-#define OPTIONSTRING "+abcd:fhi:lmn:op:qrstvuw:x:y"
-#define TMPFILE_PREFIX QDir::homePath() + "/.kdocker."
+public:
+    static const QString ORG_NAME;
+    static const QString DOM_NAME;
+    static const QString APP_NAME;
+    static const QString APP_VERSION;
 
-const QString ABOUT = QObject::tr("KDocker will help you dock any application into the system tray. This means you can dock openoffice, xmms, firefox, thunderbird, anything! Just point and click. Works for all NET WM compliant window managers - that includes KDE, GNOME, Xfce, Fluxbox and many more.\n\nCreated by %1. Updated and maintained by %2.").arg("Girish Ramakrishnan").arg("John Schember");
+    static const char *OPTIONSTRING;
+
+    static const QString ABOUT_MESSAGE;
+};
 
 #endif	/* _CONSTANTS_H */
-
