@@ -21,33 +21,36 @@
 #ifndef _KDOCKER_H
 #define	_KDOCKER_H
 
-#include <QApplication>
 #include <QStringList>
+#include <QObject>
+
 #include "trayitemmanager.h"
 
-class KDocker : public QApplication {
+class KDocker : public QObject {
     Q_OBJECT
 
 public:
-    KDocker(int &argc, char **argv);
+    KDocker();
     ~KDocker();
 
-    TrayItemManager *trayItemManager();
-    bool x11EventFilter(XEvent *event);
+    void undockAll();
+
+    void preProcessCommand(int argc, char **argv);
+    bool x11EventFilter(XEvent *ev);
+
+public slots:
+    void run();
+
+private slots:
+    void handleMessage(const QString &args);
 
 private:
-    void notifyPreviousInstance(Window prevInstance, QStringList args = QStringList());
-    void preProcessCommand(int argc, char **argv);
-    void setupTranslator();
-
     void printAbout();
     void printHelp();
     void printUsage();
     void printVersion();
 
     TrayItemManager *m_trayItemManager;
-    QTranslator *m_translator;
-
 };
 
 #endif	/* _KDOCKER_H */
